@@ -14,6 +14,7 @@ from ExifTags import TAGS
 
 from optparse import make_option
 from django.core.management.base import BaseCommand, CommandError
+from django.template.defaultfilters import slugify
 from django.template import Context, Template
 from django.conf import settings as conf
 import rgallery.models as mymodels
@@ -156,6 +157,7 @@ class Command(BaseCommand):
         client, bucket = get_contents(srcdir, debug)
 
         for file in bucket:
+            #import pdb; pdb.set_trace()
             try:
                 filepath = file['path']
             except:
@@ -168,7 +170,8 @@ class Command(BaseCommand):
             except:
                 print "[***] La imagen %s No esta en bd, descargar y agregar a bbdd y hacer thumb" % os.path.basename(filepath)
                 #import pdb; pdb.set_trace()
-                nombre_imagen = str(os.path.basename(filepath)).replace('/', '').replace(' ','_').replace(':','-')
+                nombre_imagen = "%s%s" % (slugify(str(os.path.splitext(os.path.basename(filepath))[0]).replace('/', '').replace(' ','_').replace(':','-')),
+                                        str(os.path.splitext(os.path.basename(filepath))[1]))
 
                 # Descargar original a img
                 img = download(client, file, nombre_imagen, srcdir, destdir, debug)
@@ -198,7 +201,8 @@ class Command(BaseCommand):
                     print "      Guardada: %s/%s" % (destdir, nombre_imagen)
                 else:
                     descargadas += 1
-                    nombre_imagen_repe = str(os.path.basename(filepath)).replace('/','').replace(' ','_').replace(':','-').replace('.jpg','') + '_1.jpg'
+                    nombre_imagen_repe = "%s_1%s" % (slugify(str(os.path.splitext(os.path.basename(filepath))[0]).replace('/', '').replace(' ','_').replace(':','-')),
+                                                     str(os.path.splitext(os.path.basename(filepath))[1]))
                     im.image = "uploads/photos/" + nombre_imagen_repe
                     im.save()
                     im2.save(destdir + '/' + nombre_imagen_repe)
@@ -206,7 +210,7 @@ class Command(BaseCommand):
 
                 # Creamos thumbs
                 for thumb in thumbs:
-                    print "Thumb %sx%s" % (thumb, thumb)
+                    print "      Thumb %sx%s" % (thumb, thumb)
                     im = get_thumbnail(im, "%sx%s" % (thumb, thumb))
 
             total += 1
